@@ -32,14 +32,13 @@ class EntityGeneratorCSV(CSVParser.CSVParser):
 
         super().__init__(filename)
 
-        self.props_keys       = [x for x in self.header[1:] if not x.startswith(CSVParser.CONTRAINTS_PREFIX) ]
+        self.props_keys       = [x for x in self.header[1:] if not x.startswith(CSVParser.CONTRAINTS_PREFIX)]
         self.constraints_keys = [x for x in self.header[1:] if x.startswith(CSVParser.CONTRAINTS_PREFIX) ]
 
     def __getitem__(self, idx):
 
-        data = {
-            "class": self.df.loc[idx, ENTITY_CLASS]
-        }
+        data = {}
+        data["class"] = self.df.loc[idx, ENTITY_CLASS]
 
         properties  = self.parse_properties(self.df, idx)
         constraints = self.parse_constraints(self.df, idx)
@@ -83,6 +82,7 @@ class EntityLoader(ParallelLoader.ParallelLoader):
     def generate_batch(self, entity_data):
 
         q = []
+        blobs = []
 
         for data in entity_data:
 
@@ -96,11 +96,11 @@ class EntityLoader(ParallelLoader.ParallelLoader):
                 ae["AddEntity"][PROPERTIES] = data[PROPERTIES]
 
             if CONSTRAINTS in data:
-                ae["AddEntity"][CONSTRAINTS] = data[CONSTRAINTS]
+                ae["AddEntity"]["if_not_found"] = data[CONSTRAINTS]
 
             q.append(ae)
 
         if self.dry_run:
             print(q)
 
-        return q, []
+        return q, blobs
