@@ -104,16 +104,26 @@ class ParallelLoader:
 
     def print_stats(self):
 
-        print("====== ApertureDB Loader Stats ======")
         times = np.array(self.times_arr)
-        print("Avg Query time(s):", np.mean(times))
+        total_queries_exec = len(times)
+        inserted_elements  = self.total_elements
+
+        print("============ ApertureDB Loader Stats ============")
+        print("Total time (s):", self.ingestion_time)
+        print("Total queries executed:", total_queries_exec)
+        print("Avg Query time (s):", np.mean(times))
         print("Query time std:", np.std (times))
         print("Avg Query Throughput (q/s)):",
-            1 / np.mean(times) * self.numthreads)
+                1 / np.mean(times) * self.numthreads)
 
-        print("Total time(s):", self.ingestion_time)
         msg = "(" + self.type + "/s):"
         print("Overall insertion throughput", msg,
-            self.total_elements / self.ingestion_time)
-        print("Total errors encountered:", self.error_counter)
-        print("===========================================")
+                self.total_elements / self.ingestion_time)
+
+        if self.error_counter > 0:
+            print("Total errors encountered:", self.error_counter)
+            inserted_elements -= self.error_counter * self.batchsize
+            print("Errors (%):", 100 * self.error_counter / total_queries_exec)
+
+        print("Total inserted elements:", inserted_elements)
+        print("=================================================")
